autowisp.light_curves.collect_light_curves module — AutoWISP documentation

# autowisp.light_curves.collect_light_curves module

## Class Inheritance Diagram

Functions for creating light curves from DR files.

class autowisp.light_curves.collect_light_curves.DecodingStringFormatter

  Bases: `Formatter`

  Add one more conversion type: `'d'` that calls decode on the arg.

  convert_field(value, conversion)

    If conversion is `'d'` -> `value.decode()` else pass to parent

autowisp.light_curves.collect_light_curves.collect_light_curves(dr_filenames, configuration, mark_start, mark_end, *, dr_fname_parser=<function parse_fname_keywords>, optional_header=None, observatory=None, **path_substitutions)

  Add the data from a collection of DR files to LCs, creating LCs if needed.

  Parameters:

    - dr_filenames ([str]) – The filenames of the data reduction files to add to LCs.

    - configuration – Object with attributes configuring the LC collection procedure.

    - path_substitutions – Any substitutions to resolve paths within DR and LC files to data to read/write (e.g. versions of various componenents).

    - dr_fname_parser – See same name argument to LCDataIO::create().

    - optional_header – See same name argument to LCDataIO::create().

  Returns:

    [(src ID part 1, src ID part 2, …)];

      The sources for which new lightcurves were created.

autowisp.light_curves.collect_light_curves.get_combined_sources(dr_filenames, **dr_path_substitutions)

  Return all sources which are in at lest one of the DR files.